package WebGUI::i18n::Dutch::Asset_Navigation;
use utf8;
our $I18N = {
  '' => {
    'lastUpdated' => '1199788175',
    'message' => '&nbsp;'
  },
  1096 => {
    'lastUpdated' => '1150103826',
    'message' => 'Navigatie sjabloon'
  },
  '1096 description' => {
    'lastUpdated' => '1150103857',
    'message' => 'Kies een sjabloon dat gebruikt wordt voor het tonen van de navigatie.'
  },
  1097 => {
    'lastUpdated' => '1222876849',
    'message' => 'Deze variabelen zijn beschikbaar voor het navigatie sjabloon. <p><strong>currentPage</strong> refereert naar de pagina die de gebruiker op dat moment bekijkt. <strong>page</strong> refereert naar alle pagina\'s in de <strong>page_loop</strong>.</p><p>&nbsp;</p><p>Wanneer er naar een pagina gerefereerd wordt, is elke eigenschap van het Asset beschikbaar. De meest nuttige staan hieronder vermeld:</p>'
  },
  22 => {
    'lastUpdated' => '1150103921',
    'message' => 'Bewerk navigatie'
  },
  30 => {
    'lastUpdated' => '1150103934',
    'message' => 'Laat de systeem paginas zien'
  },
  '30 description' => {
    'lastUpdated' => '1207826530',
    'message' => 'Moeten de menus die door het macro gemaakt worden de systeem paginas zoals de prullenbak, het klembord, pagina niet gevonden enzovoort tonen. Wanneer beheerder en inhoud beheerders systeem paginas mogen zien, selecteer dan ja en gebruik het navigatie sjabloon om ze te verbergen.'
  },
  31 => {
    'lastUpdated' => '1149260111',
    'message' => 'Toon verborgen paginas'
  },
  '31 description' => {
    'lastUpdated' => '1207826737',
    'message' => '<p>Moeten paginas die verborgen zijn wel getoond worden in de menu\'s? Als het gewenst (net als bij systeem paginas) is dat bepaalde groepen de verborgen paginas kunnen zien, selecteer dan Ja en bepaal met het navigatie sjabloon wie deze paginas in het menu te zien krijgt.</p><p>N.B.: Elke gebruiker die in de beheer modus zit zal automatisch elke pagina zien die hij/zij kan bewerken. Hierbij maakt het niet uit of ze verborgen zijn of hoe deze instelling is gedaan. &nbsp;</p>'
  },
  32 => {
    'lastUpdated' => '1150104729',
    'message' => 'Laat paginas zonder privileges zien'
  },
  '32 description' => {
    'lastUpdated' => '1151065084',
    'message' => 'Moeten de door het macro aangemaakte menus de paginas meenemen die de huidige ingelogde gebruiker geen rechten heeft voor het bekijken? '
  },
  'Ancestor End Point' => {
    'lastUpdated' => '1151065271',
    'message' => 'Voorouder eindpunt'
  },
  'Ancestor End Point description' => {
    'lastUpdated' => '1151065241',
    'message' => 'Als het type startpunt relatief ten opzichte van de huidige URL is, is dit het aantal niveaus boven de huidige URL waar de navigatie moet beginnen. '
  },
  'Ancestors' => {
    'lastUpdated' => '1151063682',
    'message' => 'Voorouders'
  },
  'Descendant End Point' => {
    'lastUpdated' => '1151065287',
    'message' => 'Kleinkind eindpunt'
  },
  'Descendant End Point description' => {
    'lastUpdated' => '1151065334',
    'message' => 'Het aantal niveaus naar beneden vanaf het startpunt waar de navigatie moet ophouden. '
  },
  'Descendants' => {
    'lastUpdated' => '1149260357',
    'message' => 'Nakomelingen'
  },
  'Infinity' => {
    'lastUpdated' => '1150728639',
    'message' => 'Oneindig'
  },
  'Pedigree' => {
    'lastUpdated' => '1151065472',
    'message' => 'Stamboom'
  },
  'Relative To Current URL' => {
    'lastUpdated' => '1151065509',
    'message' => 'Relatief ten opzichte van de huidige URL '
  },
  'Relative To Root' => {
    'lastUpdated' => '1151065528',
    'message' => 'Relatief ten opzichte van de root.'
  },
  'Relatives To Include' => {
    'lastUpdated' => '1151065863',
    'message' => 'Mee te nemen verwanten'
  },
  'Relatives To Include description' => {
    'lastUpdated' => '1208524346',
    'message' => '<p>De navigatie asset kan paginas uitfilteren die niet in de navigatie moeten voorkomen. Selecteer de typen paginas die meegenomen moeten worden:</p><p>Voorouders:</p><p>&nbsp;&nbsp;&nbsp; Paginas die hoger staan in de stamboom dan de huidige pagina</p><p>Zelf</p><p>&nbsp;&nbsp;&nbsp; De huidige pagina</p><p>Zusters</p><p>&nbsp;&nbsp;&nbsp; Paginas op hetzelfde niveau</p><p>Kleinkinderen</p><p>&nbsp;&nbsp;&nbsp; Paginas die lager staan in de stamboom dan de huidige pagina</p><p>Stamboom</p><p>&nbsp;&nbsp;&nbsp; Wanneer een andere startpagina wordt gebruikt, selecteer met deze optie de voorouders, zusters en kleinkinderen van die pagina.&nbsp;</p>'
  },
  'Self' => {
    'lastUpdated' => '1149261323',
    'message' => 'Zelf'
  },
  'Siblings' => {
    'lastUpdated' => '1151063778',
    'message' => 'Zusters'
  },
  'Specific URL' => {
    'lastUpdated' => '1150729256',
    'message' => 'Specifiek URL'
  },
  'Start Point' => {
    'lastUpdated' => '1149261315',
    'message' => 'Begin punt'
  },
  'Start Point Type' => {
    'lastUpdated' => '1150728800',
    'message' => 'Type beginpunt'
  },
  'Start Point Type description' => {
    'lastUpdated' => '1150728924',
    'message' => 'Kies hier waar de navigatie moet beginnen met het kiezen van paginas. Moet dat op een specifiek URL, een pagina relatief ten opzichte van de huidige pagina of een relatief ten opzichte van de root pagina.'
  },
  'Start Point description' => {
    'lastUpdated' => '1150728978',
    'message' => 'Dit is de plaats waar de navigatie begint met het kiezen van paginas, dit is gebaseerd op het type beginpunt.'
  },
  'Where do you want to go?' => {
    'lastUpdated' => '1231520350',
    'message' => 'Waar wilt u naartoe?'
  },
  'ancestorEndPoint' => {
    'lastUpdated' => '1170690319',
    'message' => 'Afhankelijk van het type startpunt, hoeveel niveau\'s daarboven begonnen moet worden met het weergeven van assets, meestal pagina\'s, in het menu. '
  },
  'assetName' => {
    'lastUpdated' => '1150729001',
    'message' => 'Navigatie'
  },
  'assetsToInclude' => {
    'lastUpdated' => '1254902486',
    'message' => 'Een variabele (string) die het soort assets - naar relatie - bevat, die moeten worden opgenomen in het menu. Deze worden gescheiden door nieuwe regels. Opties zijn voorouders, het asset zelf, zusterassets, afstammelingen en stamboom.'
  },
  'currentPage.assetId' => {
    'lastUpdated' => '1166195298',
    'message' => 'De ID van de huidige pagina.'
  },
  'currentPage.hasChild' => {
    'lastUpdated' => '1166195318',
    'message' => 'Een functie die aangeeft of de huidige pagina dochters heeft.'
  },
  'currentPage.hasSibling' => {
    'lastUpdated' => '1166195329',
    'message' => 'Een functie die aangeeft of de huidige pagina zusters heeft.'
  },
  'currentPage.hasViewableChildren' => {
    'lastUpdated' => '1166195344',
    'message' => 'Een functie die aangeeft of de huidige pagina dochters heeft die door de gebruiker bekeken kunnen worden.'
  },
  'currentPage.hasViewableSiblings' => {
    'lastUpdated' => '1166195359',
    'message' => 'Een functie die aangeeft of de huidige pagina zusters heeft die door de gebruiker bekeken kunnen worden.'
  },
  'currentPage.isHome' => {
    'lastUpdated' => '1166195418',
    'message' => 'Een functie die aangeeft of de huidige pagina de beginpagina van de site is.'
  },
  'currentPage.menuTitle' => {
    'lastUpdated' => '1166195430',
    'message' => 'De titel in het menu van de huidige pagina.'
  },
  'currentPage.newWindow' => {
    'lastUpdated' => '1166195442',
    'message' => 'Een functie die aangeeft of de huidige pagina in een nieuw venster geopend moet worden.'
  },
  'currentPage.ownerUserId' => {
    'lastUpdated' => '1166195455',
    'message' => 'De ID van de eigenaar van de huidige pagina.'
  },
  'currentPage.parentId' => {
    'lastUpdated' => '1166195475',
    'message' => 'De ID van de ouder van de huidige pagina.'
  },
  'currentPage.rank' => {
    'lastUpdated' => '1166195487',
    'message' => 'De positie van de huidige pagina ten opzichte van haar zusters.'
  },
  'currentPage.synopsis' => {
    'lastUpdated' => '1203437774',
    'message' => 'De samenvatting van de huidige pagina.'
  },
  'currentPage.title' => {
    'lastUpdated' => '1166195507',
    'message' => 'De titel van de huidige pagina.'
  },
  'currentPage.url' => {
    'lastUpdated' => '1166195515',
    'message' => 'De URL van de huidige pagina.'
  },
  'descendantEndPoint' => {
    'lastUpdated' => '1170690339',
    'message' => 'Afhankelijk van het type startpunt, hoeveel niveau\'s met assets, meestal pagina\'s, daaronder moeten worden weergegeven in het menu. '
  },
  'indent' => {
    'lastUpdated' => '1151063309',
    'message' => 'Het nummer van het object in de kring. '
  },
  'mimeType' => {
    'lastUpdated' => '1151064066',
    'message' => 'Type MIME'
  },
  'mimeType description' => {
    'lastUpdated' => '1151064656',
    'message' => 'Hiermee kan het type MIME ingesteld worden voor deze asset op het moment dat het via het web bekeken wordt. Zo kunnen CSS, gewone tekst, javascript en andere tekstbestanden direct uit het WebGUI assets systeem gehaald worden. Dit staat standaard op <strong>text/html</strong>. '
  },
  'mimeType variable' => {
    'lastUpdated' => '1170690357',
    'message' => 'Het "MIME-type" van de pagina waarop de menu wordt weergegeven.'
  },
  'navigation asset template variables body' => {
    'lastUpdated' => '1170690367',
    'message' => 'Elk asset maakt een set variabelen beschikbaar die gebruikt kunnen worden in de meeste van zijn sjablonen. Deze variabelen zijn gebaseerd op interne eigenschappen, waardoor ze niet allemaal even bruikbaar zijn voor het gebruik in sjablonen. '
  },
  'navigation asset template variables title' => {
    'lastUpdated' => '1170690376',
    'message' => 'Menu asset sjabloonvariabelen'
  },
  'page.absDepth' => {
    'lastUpdated' => '1151066300',
    'message' => 'De absolute diepte van deze pagina ten opzichte van de naamloze root.'
  },
  'page.assetId' => {
    'lastUpdated' => '1151066334',
    'message' => 'De asset identificatie van deze pagina. '
  },
  'page.depthDiff' => {
    'lastUpdated' => '1290091508',
    'message' => 'Het verschil in diepte tussen deze en de vorige pagina; previous.absDepth minus page.absDepth. Overigens is parent.absDepth geen sjabloon variabele. Voor de allereerste pagina (die geen vorige pagina heeft) wordt dit op 0 gesteld.'
  },
  'page.depthDiffIsN' => {
    'lastUpdated' => '1151066533',
    'message' => 'Dit is correct als de variabele <strong>page.depthDiff</strong> gelijk is aan N. N kan zowel positief als negatief zijn.'
  },
  'page.depthDiff_loop' => {
    'lastUpdated' => '1151066706',
    'message' => 'Als <strong>page.depthDiff</strong> groter is dan nul, is dit een kring die zoveel keer als de grootte van deze variabele doorlopen wordt. Deze kring bevat geen variabelen. '
  },
  'page.depthIsN' => {
    'lastUpdated' => '1207841150',
    'message' => '<p>Een functie die aangeeft of de diepte van deze pagina N is. Dit kan gebruikt worden voor het synchroniseren van de layout van een bepaald niveau.</p><p>&nbsp;</p><p>&lt;tmpl_if page.depthIs1&gt;<br /> &nbsp;&nbsp; &lt;img xsrc=&quot;level1.gif&quot;&gt;<br />&lt;tmpl_else&gt;<br />&nbsp;&nbsp; &lt;img xsrc=&quot;defaultBullet.gif&quot;&gt;<br />&lt;/tmpl_if&gt; </p>'
  },
  'page.hasChild' => {
    'lastUpdated' => '1151066960',
    'message' => 'Een functie die laat zien of deze pagina een dochter heeft. Met andere woorden: deze functie klopt als deze pagina een moeder is. '
  },
  'page.hasViewableChildren' => {
    'lastUpdated' => '1207841097',
    'message' => 'Een functie die aangeeft of deze pagina een dochter heeft die bekeken kan worden.'
  },
  'page.inBranch' => {
    'lastUpdated' => '1166195379',
    'message' => 'Een voorwaardelijke functie die de keuze maakt uit de opties <strong>isAncestor</strong>, <strong>isSister</strong>, <strong>isBasepage</strong> en <strong> isDescendant</strong>.'
  },
  'page.inBranchRoot' => {
    'lastUpdated' => '1166195549',
    'message' => 'Dit klopt als deze pagina een ondergeschikte is van de root pagina van de huidige pagina.'
  },
  'page.indent' => {
    'lastUpdated' => '1166195588',
    'message' => 'Een variabele die de inspringafstand van de huidige pagina bevat. De standaard inspringafstand is drie spaties. Voor een meer flexibel gebruik van de inspringfunctie kan de <strong>page.indent_loop</strong> gebruikt worden. '
  },
  'page.indent_loop' => {
    'lastUpdated' => '1151068659',
    'message' => 'Een kring die zo vaak doorlopen wordt als de grootte van <strong>page.relDepth</strong>.'
  },
  'page.isAncestor' => {
    'lastUpdated' => '1166195601',
    'message' => 'Dit geeft aan of deze pagina een voorouder is van de huidige pagina.'
  },
  'page.isBranchRoot' => {
    'lastUpdated' => '1151068843',
    'message' => 'Dit geeft aan of deze pagina een root pagina is.'
  },
  'page.isChild' => {
    'lastUpdated' => '1166195642',
    'message' => 'Dit geeft aan of deze pagina een dochter is van de huidige pagina.'
  },
  'page.isContainer' => {
    'lastUpdated' => '1166195685',
    'message' => 'Dit geeft aan of deze pagina een container asset is. Dit betekent dat deze andere Assets kan bevatten. Voorbeelden van container Assets zijn pagina\'s, mappen en Dashboards.'
  },
  'page.isCurrent' => {
    'lastUpdated' => '1166195699',
    'message' => 'Een functie die laat zien of deze pagina de huidige pagina is of niet.'
  },
  'page.isDescendant' => {
    'lastUpdated' => '1238673269',
    'message' => 'Een conditie, die aangeeft of deze pagina een onderpagina van de actuele pagina is.'
  },
  'page.isDescendent' => {
    'lastUpdated' => '1166195715',
    'message' => 'Dit geeft aan of deze pagina een ondergeschikte is van de huidige pagina.'
  },
  'page.isHidden' => {
    'lastUpdated' => '1151069016',
    'message' => 'Een functie die laat zien of dit een verborgen pagina is.'
  },
  'page.isParent' => {
    'lastUpdated' => '1166195730',
    'message' => 'Dit laat zien of deze pagina de ouder is van de huidige pagina. '
  },
  'page.isRankedFirst' => {
    'lastUpdated' => '1170690385',
    'message' => 'Deze eigenschap laat zien of deze pagina de eerste is in dit niveau.'
  },
  'page.isRankedLast' => {
    'lastUpdated' => '1207841334',
    'message' => 'Deze eigenschap laat zien of deze pagina de laatste is op dit niveau.'
  },
  'page.isSibling' => {
    'lastUpdated' => '1166195749',
    'message' => 'Dit laat zien of deze pagina een zuster is van de huidige pagina.'
  },
  'page.isSystem' => {
    'lastUpdated' => '1151069363',
    'message' => 'Een functie die aangeeft of deze pagina een systeempagina is (Prullenmand, Klembord, enz.).'
  },
  'page.isTopOfBranch' => {
    'lastUpdated' => '1151069455',
    'message' => 'Een functie die aangeeft of dit een bovenliggende pagina is (zuster van de root).'
  },
  'page.isUtility' => {
    'lastUpdated' => '1208524572',
    'message' => 'Dit laat zien of deze pagina een gereedschap asset is. Een gereedschap Asset is een Asset die meestal niet direct door gebruikers bekeken mag worden zoals een Afbeelding Asset, Sjablonen en Tekstverwerkers.'
  },
  'page.isViewable' => {
    'lastUpdated' => '1151069610',
    'message' => 'Dit laat zien of de gebruiker het recht heeft deze pagina te bekijken.'
  },
  'page.menuTitle' => {
    'lastUpdated' => '1151069631',
    'message' => 'De menu titel van deze pagina.'
  },
  'page.newWindow' => {
    'lastUpdated' => '1151069671',
    'message' => 'Een functie die laat zien of deze pagina in een nieuw venster geopend moet worden.'
  },
  'page.ownerUserId' => {
    'lastUpdated' => '1151069699',
    'message' => 'De gebruikers identificatie van de eigenaar van deze pagina.'
  },
  'page.parent.assetId' => {
    'lastUpdated' => '1207841373',
    'message' => 'De asset identificatie van de moeder van deze pagina.'
  },
  'page.parent.menuTitle' => {
    'lastUpdated' => '1151069750',
    'message' => 'De menu titel van de moeder van deze pagina.'
  },
  'page.parent.newWindow' => {
    'lastUpdated' => '1151069782',
    'message' => 'Dit laat zien of de moeder van deze pagina in een nieuw venster geopend moet worden.'
  },
  'page.parent.ownerUserId' => {
    'lastUpdated' => '1151069815',
    'message' => 'De gebruikers identificatie van de moeder van deze pagina.'
  },
  'page.parent.parentId' => {
    'lastUpdated' => '1151069863',
    'message' => 'De asset identificatie van de grootmoeder van deze pagina. '
  },
  'page.parent.rank' => {
    'lastUpdated' => '1155895652',
    'message' => 'De rang van de moeder van deze pagina.'
  },
  'page.parent.synopsis' => {
    'lastUpdated' => '1203437770',
    'message' => 'De samenvatting van de moeder van deze pagina.'
  },
  'page.parent.title' => {
    'lastUpdated' => '1151069927',
    'message' => 'De titel van de moeder van deze pagina.'
  },
  'page.parent.url' => {
    'lastUpdated' => '1151069991',
    'message' => 'De tot URL bewerkte titel van deze pagina.'
  },
  'page.parentId' => {
    'lastUpdated' => '1151070049',
    'message' => 'De asset identificatie van de moeder van deze pagina.'
  },
  'page.rank' => {
    'lastUpdated' => '1151070105',
    'message' => 'De rang van deze pagina ten opzichte van haar zusters. '
  },
  'page.relDepth' => {
    'lastUpdated' => '1150730770',
    'message' => 'De diepte van deze pagina (relatief ten opzichte van het beginpunt).'
  },
  'page.relativeDepthIsN' => {
    'lastUpdated' => '1207841226',
    'message' => 'Een functie die aangeeft of de diepte van deze pagina N is, relatief ten opzichte van de beginpagina.'
  },
  'page.synopsis' => {
    'lastUpdated' => '1203437763',
    'message' => 'De samenvatting van deze pagina'
  },
  'page.title' => {
    'lastUpdated' => '1150729109',
    'message' => 'De titel van deze pagina'
  },
  'page.url' => {
    'lastUpdated' => '1150729027',
    'message' => 'Het complete URL van deze pagina.'
  },
  'page_loop' => {
    'lastUpdated' => '1246976154',
    'message' => 'Een kring met informatie over de pagina, deze is genest en hierarchisch gesorteerd. Elke eigenschap van een Asset is beschikbaar en heeft de naam <strong>page.<em>propertyName</em></strong>, waar propertyName vervangen moet worden door de eigenschap die gebruikt wordt zoals className of assetSize. Hieronder zijn enkele genoemd. Voor de volledige lijst wordt naar de sjabloon variabelen van elk Asset verwezen.'
  },
  'preview' => {
    'lastUpdated' => '1246976040',
    'message' => 'Voorvertoning navigatie'
  },
  'reverse page loop' => {
    'lastUpdated' => '1155895667',
    'message' => 'Omgekeerde pagina-loop'
  },
  'reverse page loop description' => {
    'lastUpdated' => '1155895707',
    'message' => 'Keer de volgorde van alle pagina&#39;s om, maar handhaaf de hi&euml;rarchie. '
  },
  'reversePageLoop' => {
    'lastUpdated' => '1170690407',
    'message' => 'Deze variabele geeft aan of de assets van boven naar beneden of in omgekeerde volgorde moeten worden weergegeven in het menu.'
  },
  'showHiddenPages' => {
    'lastUpdated' => '1170690418',
    'message' => 'Deze variabele geeft aan of verborgen pagina\'s moeten worden weergegeven in het menu of niet.'
  },
  'showSystemPages' => {
    'lastUpdated' => '1207817947',
    'message' => 'Deze variabele geeft aan of systeempagina\'s, zoals de prullenbak, moeten worden weergegeven in dit menu.'
  },
  'showUnprivilegedPages' => {
    'lastUpdated' => '1208524631',
    'message' => 'Deze variabele geeft aan of pagina\'s (assets) die deze gebruiker niet mag bekijken wel moeten worden weergegeven in dit menu. '
  },
  'startPoint' => {
    'lastUpdated' => '1170690490',
    'message' => 'Afhankelijk van het type startpunt, geeft deze variabele aan bij welke pagina dit menu begint het menu op te bouwen.'
  },
  'startType' => {
    'lastUpdated' => '1207841426',
    'message' => 'Een variabele (tekst) die aangeeft hoe het startpunt voor het menu wordt bepaald. Dit kan zijn &quot;specificUrl&quot; (een volledige webgui url), &quot;relativeToCurrentUrl&quot; (relatief ten opzichte van de huidige url) of &quot;relativeToRoot&quot; (relatief ten opzichte van de root van de site).'
  },
  'templateId' => {
    'lastUpdated' => '1170690286',
    'message' => 'De ID van het sjabloon dat gebruikt wordt om dit menu weer te geven. '
  }
}
;

1;
